@@ -26,12 +26,16 @@ import xml.etree.ElementTree as ET
 
 import setzer.app.settings as settingscontroller
 import setzer.app.autocomplete_provider.autocomplete_provider as autocomplete_provider
+import setzer.app.color_manager as color_manager
 import setzer.app.font_manager as font_manager
+import setzer.app.forward_sync_manager as forward_sync_manager
 import setzer.helpers.popover_menu_builder as popover_menu_builder
 
 
 class ServiceLocator(object):
 
+    main_window = None
+    workspace = None
     settings = None
     setzer_version = None
     resources_path = None
@@ -42,7 +46,9 @@ class ServiceLocator(object):
     packages_dict = None
     source_language_manager = None
     source_style_scheme_manager = None
+    color_manager = None
     font_manager = None
+    forward_sync_manager = None
 
     def init_main_window(main_window):
         ServiceLocator.main_window = main_window
@@ -50,18 +56,15 @@ class ServiceLocator(object):
     def get_main_window():
         return ServiceLocator.main_window
 
-    def get_theme_fg_color():
-        return ServiceLocator.main_window.get_style_context().lookup_color('theme_fg_color')[1]
+    def init_workspace(workspace):
+        ServiceLocator.workspace = workspace
 
-    def get_theme_bg_color():
-        return ServiceLocator.main_window.get_style_context().lookup_color('theme_bg_color')[1]
-
-    def get_error_color():
-        return ServiceLocator.main_window.get_style_context().lookup_color('error_color')[1]
+    def get_workspace():
+        return ServiceLocator.workspace
 
     def get_is_dark_mode():
-        fg_color = ServiceLocator.get_theme_fg_color()
-        bg_color = ServiceLocator.get_theme_bg_color()
+        fg_color = ServiceLocator.get_color_manager().get_theme_color('theme_fg_color')
+        bg_color = ServiceLocator.get_color_manager().get_theme_color('theme_bg_color')
         return (fg_color.red + fg_color.green + fg_color.blue) * fg_color.alpha > (bg_color.red + bg_color.green + bg_color.blue) * bg_color.alpha
 
     def get_regex_object(pattern):
@@ -99,6 +102,16 @@ class ServiceLocator(object):
             ServiceLocator.font_manager = font_manager.FontManager(ServiceLocator.get_main_window(), ServiceLocator.get_settings())
         return ServiceLocator.font_manager
 
+    def get_color_manager():
+        if ServiceLocator.color_manager == None:
+            ServiceLocator.color_manager = color_manager.ColorManager(ServiceLocator.get_main_window())
+        return ServiceLocator.color_manager
+
+    def get_forward_sync_manager():
+        if ServiceLocator.forward_sync_manager == None:
+            ServiceLocator.forward_sync_manager = forward_sync_manager.ForwardSyncManager(ServiceLocator.get_workspace())
+        return ServiceLocator.forward_sync_manager
+
     def get_popover_menu_builder():
         if ServiceLocator.popover_menu_builder == None:
             ServiceLocator.popover_menu_builder = popover_menu_builder.PopoverMenuBuilder()
