@@ -74,7 +74,7 @@ class DocumentBibTeX(Document):
     def get_file_ending(self):
         return 'bib'
 
-    def get_is_master(self):
+    def get_is_root(self):
         return False
 
     def is_latex_document(self):
