@@ -23,14 +23,14 @@ from setzer.app.service_locator import ServiceLocator
 class LaTeXLogParser():
 
     def __init__(self):
-        self.doc_regex = ServiceLocator.get_regex_object(r'( *\((.*\.tex))')
+        self.doc_regex = ServiceLocator.get_regex_object(r'(\(([^\(\)]*\.(?:tex|gls)))')
         self.item_regex = ServiceLocator.get_regex_object(r'((?<!.) *' + 
     r'(?:Overfull \\hbox|Underfull \\hbox|' + 
-    r'No file .*\.|File .* does not exist\.|! I can' + "'" + r't find file\.|! File .* not found\.|' +
+    r'No file .*\.|File .* does not exist\.|' +
     r'(?:LaTeX|pdfTeX|LuaTeX|Package|Class) .*Warning.*:|LaTeX Font Warning:|' +
-    r'! Undefined control sequence\.|! Missing (?:.*) inserted.|! Package .* Error:|! (?:LaTeX|LuaTeX) Error:).*\n)')
+    r'! ).*\n)')
         self.badbox_line_number_regex = ServiceLocator.get_regex_object(r'lines ([0-9]+)--([0-9]+)')
-        self.other_line_number_regex = ServiceLocator.get_regex_object(r'(l.| input line \n| input line )([0-9]+)( |.)')
+        self.other_line_number_regex = ServiceLocator.get_regex_object(r'(l\.| input line \n| input line )([0-9]+)( |\.)')
 
     def parse_build_log(self, tex_filename):
         log_filename = os.path.dirname(tex_filename) + '/' + os.path.basename(tex_filename).rsplit('.tex', 1)[0] + '.log'
@@ -176,6 +176,11 @@ class LaTeXLogParser():
                     line_number = self.bl_get_line_number(line, matchiter)
                     log_messages['error'].append((None, line_number, text))
 
+                elif line.startswith('! Package'):
+                    text = self.get_text(line[2:], matchiter, True)
+                    line_number = self.bl_get_line_number(line, matchiter)
+                    log_messages['error'].append(('Undefined control sequence', line_number, text))
+
                 elif line.startswith('File') and line.endswith(' does not exist.\n'):
                     text = line.strip()
                     line_number = -1
@@ -187,16 +192,28 @@ class LaTeXLogParser():
                     log_messages['error'].append((None, line_number, text))
 
                 elif line.startswith('! File'):
-                    text = line[2:].strip()
+                    text = self.get_text(line[2:])
                     line_number = self.bl_get_line_number(line, matchiter)
                     log_messages['error'].append((None, line_number, text))
 
-                elif line.startswith('! '):
+                elif line.startswith('! ') and not line.startswith('!  ==> Fatal'):
                     text = line[2:].strip()
                     line_number = self.bl_get_line_number(line, matchiter)
                     log_messages['error'].append((None, line_number, text))
         return log_messages
 
+    def get_text(self, line, matchiter=None, can_be_multiline=False):
+        if can_be_multiline:
+            text = line.strip()
+            if not '.' in text and len(text) > 60:
+                try:
+                    text += next(matchiter).strip()
+                except StopIteration:
+                    pass
+            return text
+        else:
+            return line.strip()
+
     def split_log_text_by_file(self, log_text, tex_filename):
         doc_texts = dict()
 
