@@ -18,7 +18,8 @@
 import gi
 gi.require_version('Poppler', '0.18')
 from gi.repository import Poppler
-import PyPDF2
+from pdfminer.pdfpage import PDFPage
+from pdfminer.pdftypes import PDFObjRef
 
 import os.path
 import math
@@ -34,6 +35,7 @@ import setzer.document.latex.preview.preview_page_renderer as preview_page_rende
 import setzer.document.latex.preview.zoom_widget.zoom_widget as zoom_widget
 import setzer.document.latex.preview.paging_widget.paging_widget as paging_widget
 from setzer.helpers.observable import Observable
+from setzer.helpers.timer import timer
 
 
 class Preview(Observable):
@@ -48,7 +50,11 @@ class Preview(Observable):
 
         self.poppler_document_lock = thread.allocate_lock()
         self.poppler_document = None
-        self.links = dict()
+        self.links_lock = thread.allocate_lock()
+        self.links_parsed = True
+        with self.links_lock:
+            self.links = dict()
+        self.links_parser_lock = thread.allocate_lock()
         self.number_of_pages = 0
         self.page_width = None
         self.page_height = None
@@ -63,6 +69,7 @@ class Preview(Observable):
         self.visible_synctex_rectangles_time = None
         self.pdf_loaded = False
 
+        self.is_visible = False
         self.first_show = True
 
         self.view = preview_view.PreviewView()
@@ -78,14 +85,21 @@ class Preview(Observable):
     def change_notification(self, change_code, notifying_object, parameter):
 
         if change_code == 'build_system_visibility_change':
-            is_visible = parameter
-            if is_visible:
+            self.is_visible = parameter
+            if self.is_visible:
                 self.page_renderer.activate()
             else:
                 self.page_renderer.deactivate()
+            thread.start_new_thread(self.update_links, ())
 
         if change_code == 'filename_change':
             self.set_pdf_filename_from_tex_filename(parameter)
+            self.set_pdf_date()
+            self.load_pdf()
+
+        if change_code == 'pdf_updated':
+            self.set_pdf_date()
+            self.load_pdf()
 
     def get_pdf_filename(self):
         return self.pdf_filename
@@ -99,8 +113,6 @@ class Preview(Observable):
     def set_pdf_filename(self, pdf_filename):
         if pdf_filename != self.pdf_filename:
             self.pdf_filename = pdf_filename
-        self.set_pdf_date()
-        self.load_pdf()
 
     def set_invert_pdf(self, invert_pdf):
         self.invert_pdf = invert_pdf
@@ -115,6 +127,7 @@ class Preview(Observable):
         self.number_of_pages = 0
         self.page_width = None
         self.page_height = None
+        self.links_parsed = True
         self.links = dict()
         self.xoffset = 0
         self.yoffset = 0
@@ -187,7 +200,6 @@ class Preview(Observable):
                 page_size = self.poppler_document.get_page(0).get_size()
                 self.page_width = page_size.width
                 self.page_height = page_size.height
-                self.links = dict()
                 current_min = self.page_width
                 for page_number in range(0, min(self.number_of_pages, 3)):
                     page = self.poppler_document.get_page(page_number)
@@ -198,8 +210,12 @@ class Preview(Observable):
                 current_min -= 20
                 self.vertical_margin = current_min
             self.pdf_loaded = True
+            self.document.update_can_sync()
             self.add_change_code('pdf_changed')
-            self.links = dict()
+            with self.links_lock:
+                self.links = dict()
+            self.links_parsed = False
+            thread.start_new_thread(self.update_links, ())
             self.set_zoom_fit_to_width()
             self.document.update_can_sync()
 
@@ -207,28 +223,67 @@ class Preview(Observable):
         return self.layouter.get_page_number_and_offsets_by_document_offsets(x, y)
 
     def get_links_for_page(self, page_number):
-        if not page_number in self.links:
+        with self.links_lock:
+            try:
+                return self.links[page_number]
+            except KeyError:
+                return list()
+
+    def update_links(self):
+        with self.links_parser_lock:
+            if self.links_parsed: return
+            if not self.is_visible: return
+
+            links = dict()
 
             with open(self.pdf_filename, 'rb') as file:
-                pypdf_document = PyPDF2.PdfFileReader(file)
-                page = pypdf_document.getPage(page_number).getObject()
+                for page_num, page in enumerate(PDFPage.get_pages(file)):
+                    links[page_num] = list()
+                    annots_final = self.resolve_annots(page.annots)
+                    for annot in annots_final:
+                        try:
+                            rect = annot['Rect']
+                        except KeyError:
+                            pass
+                        else:
+                            try:
+                                data = annot['A']
+                            except KeyError:
+                                pass
+                            else:
+                                try:
+                                    named_dest = data['D']
+                                except KeyError:
+                                    pass
+                                else:
+                                    dest = self.poppler_document.find_dest(named_dest.decode('utf-8'))
+                                    links[page_num].append([rect, dest, 'goto'])
+                                try:
+                                    uri = data['URI']
+                                except KeyError:
+                                    pass
+                                else:
+                                    links[page_num].append([rect, uri.decode('utf-8'), 'uri'])
+            with self.links_lock:
+                self.links = links
+                self.links_parsed = True
 
-                links = []
-                if '/Annots' in page.keys():
-                    for annotation in page['/Annots']:
-                        annotation_object = annotation.getObject()
-                        if annotation_object['/Subtype'] == '/Link':
-                            rect = annotation_object['/Rect']
-                            data = annotation_object['/A']
-                            if data['/S'] == '/GoTo':
-                                dest = self.poppler_document.find_dest(data['/D'])
-                                links.append([rect, dest, 'goto'])
-                            elif data['/S'] == '/URI':
-                                dest = data['/URI']
-                                links.append([rect, dest, 'uri'])
-            self.links[page_number] = links
+    def resolve_annots(self, annots):
+        if annots == None: return []
 
-        return self.links[page_number]
+        if type(annots) is PDFObjRef:
+            annots = annots.resolve()
+
+        if type(annots) is dict:
+            return [annots]
+        else:
+            return_value = list()
+            for annot in annots:
+                if type(annots) is dict:
+                    return_value.append(annot)
+                else:
+                    return_value += self.resolve_annots(annot)
+            return return_value
 
     def update_fit_to_width_zoom_level(self, level):
         if level != self.zoom_level_fit_to_width:
