@@ -46,6 +46,7 @@ class StateManagerLaTeX():
                         self.load_code_folding_state(document_data)
                         self.load_build_log_state(document_data)
                         self.load_preview_state(document_data)
+                        self.load_synctex_state(document_data)
 
     def load_code_folding_state(self, document_data):
         try:
@@ -55,9 +56,9 @@ class StateManagerLaTeX():
 
     def load_build_log_state(self, document_data):
         try:
-            self.document.build_log_items = document_data['build_log_items']
+            self.document.build_log_data = document_data['build_log_data']
         except KeyError:
-            self.document.build_log_items = list()
+            self.document.build_log_data = {'items': list(), 'error_count': 0, 'warning_count': 0, 'badbox_count': 0}
         try:
             self.document.has_been_built = document_data['has_been_built']
         except KeyError:
@@ -66,10 +67,14 @@ class StateManagerLaTeX():
             self.document.build_time = document_data['build_time']
         except KeyError:
             self.document.build_time = None
+
+    def load_synctex_state(self, document_data):
         try:
             self.document.has_synctex_file = document_data['has_synctex_file']
         except KeyError:
             self.document.has_synctex_file = False
+        self.document.has_synctex_file
+        self.document.update_can_sync()
 
     def load_preview_state(self, document_data):
         try:
@@ -101,7 +106,7 @@ class StateManagerLaTeX():
         document_data = dict()
         document_data['save_date'] = self.document.save_date
         document_data['folded_regions'] = self.document.get_folded_regions()
-        document_data['build_log_items'] = self.document.build_log_items
+        document_data['build_log_data'] = self.document.build_log_data
         document_data['has_been_built'] = self.document.has_been_built
         document_data['build_time'] = self.document.build_time
         document_data['has_synctex_file'] = self.document.has_synctex_file
