@@ -17,12 +17,7 @@
 
 import gi
 gi.require_version('Gtk', '3.0')
-gi.require_version('GtkSource', '3.0')
-from gi.repository import Gdk
 from gi.repository import Gtk
-import math
-
-import setzer.helpers.helpers as helpers
 
 
 class PreviewPanelView(Gtk.VBox):
